##  Previewing Diagram Templates
To preview a template with real data:
  1. Go to the Diagram Templates page.
  2. Select a template to open its preview page.
  3. Choose one or more fact sheets from the drop-down list.
You can select up to five.
  4. Optional: In the toolbar above the preview, open the View drop-down list and select a view.


The preview loads, showing each selected fact sheet’s actual data in the context of the template’s structure. All data in the preview is immediately updated and color-coded according to the selected view.
**Note**
The preview may take a moment to load if the template or data set is large.
**Example**
Open the Application Context diagram template and select applications to preview, for example, "AC Management" and "AC Management Cloud". Once the diagram loads, apply a view, for example, TIME Classification, to enrich the visualization and reveal additional details about the related business capabilities.
Previewing a Fact Sheet and Applying a View
![A gif showing how to use a preview, including how to select a fact sheet and apply a view.](https://help.sap.com/doc/72d375467c1e4dcb872dfa2998b6328d/CLOUD/en-US/loio973397dd607f473485e871d6130047a3_LowRes.gif)
If you want to keep this view for documentation, choose Save as Diagram to create a static snapshot you can annotate or share.
